*Author: Pawel Krolikowski

clear all
set more off 
cap log close

*Close log file and start logging
cap log close ProgramLog
log using "$root_dir\logs\step1_summ_stats", replace name(ProgramLog)

*set stop time for WARN, UI, UR
global folder "2021m12update2"
*Needs to be the month before the update folder above
global stoptime 2021m11
global stopyear 2021
global stopmonth 11

global scheme "scheme(s1mono)"

*Input
*Where the data are stored
global data_dir "$root_dir\data"

*Output
*Where to store figures
global fig_dir "$root_dir\figures"

*Where to store tables
global tables_dir "$root_dir\tables"

********************************************************************************
*Appending all the cleaned notice-level data from each state
use "$data_dir\data_input\2021m12update2\state_WARN\AL\WARN_AL_clean_NAICS.dta", clear

macro drop states
*Econ comm
*local states TX FL IL OH NC MI VA WA TN IN MD WI AL LA KY OR CT IA MS NM WV ID RI ND AK NY // PA NJ SC UT KS // GA 
*Latest
// local states TX FL IL OH NC MI VA WA TN IN MD WI AL LA KY OR CT IA MS NM WV ID RI ND AK NY MO AZ OK MN CO PA NJ SC UT KS GA //  SC UT KS // GA
**Kurt's DFM states only
**Step 8: keep Kurt states only
local states AZ CA CO CT FL IA IL IN KS LA MD MI MN MO MS NC NJ NY OH OR PA SC TN TX VA WA WI

foreach state of local states {
    
// 	global datapath "$save_datadropbox\data_input\2021m12update2\data\\`state'"
//
//     * append all together except the ones that have no notice date or layoff date 
//     append using "$datapath\WARN_`state'_clean_NAICS.dta", force
	
	append using "$data_dir\data_input\2021m12update2\state_WARN\\`state'\WARN_`state'_clean_NAICS.dta"
}

// gen company_short = company
// format company_short %40s

*Drop observations that are after the previous month
*e.g. if updating in Nov, stop data in Oct
drop if year==$stopyear & month_notice>$stopmonth

*save "$save_datapath\step1_ind_notices_appended.dta", replace
save "$data_dir\data_output\step1_ind_notices_appended.dta", replace

********************************************************************************
*Figure 1 and Figure A4
*use "H:\WARN_project\data\step1_ind_notices_appended.dta", clear
use "$data_dir\data_output\step1_ind_notices_appended.dta", clear

*You don't want to make date_notice missing before you save this file because
*you use some states (PA for example) later on even though you don't have exact
*notice date (just month)
*Some state only has notice month; not notice day
replace date_notice =. if state=="PA"
replace layoff_minus_notice =. if state=="PA"
replace date_notice =. if state=="NJ"
replace layoff_minus_notice =. if state=="NJ"
replace date_notice =. if state=="SC"
replace layoff_minus_notice =. if state=="SC"
*For MN we have notice date from 1999 to June 2015 but no layoff date then in the raw data
*Cleaning assigns first of the month for notice date from 1999 to Dec 2015
*From July 2015 onward we have layoff date but no notification date in the raw data
*So layoff_minus_notice is always missing for MN, but we have the exact notice date
*for month <=June 2015 and the exact layoff date for months >= July 2015
replace date_notice =. if state=="MN" & year>=2016
replace date_notice =. if state=="MN" & year==2015 & month_notice>=7
replace layoff_minus_notice =. if state=="MN"
*For AZ got notice date from them by email but not updating since then
replace date_notice =. if state=="AZ" & (year>2019 | (year==2019 & month_notice>=7))
replace layoff_minus_notice =. if state=="AZ" & (year>2019 | (year==2019 & month_notice>=7))
*KS and UT has missing layoff date; already assigned
*layoff_minus_notice is the date layoffs began (if a date range) less the notice date

* obtaining last obs date for the histogram below 
local lastobs1=tm($stoptime)
local lastobs : di %tmMon_CCYY `lastobs1'
di "`lastobs'"
format time_notice %tmCCYY

* dropping 1%
sum layoff_minus_notice, det
cap gen layoff_minus_notice_new = layoff_minus_notice if layoff_minus_notice >= r(p1) & layoff_minus_notice <=r(p99)
*25 percentile is 50 days and 75th percentile is 65 days
sum layoff_minus_notice_new if year<=2019, det
local numobs=r(N)
disp(`numobs')
sum layoff_minus_notice_new if year>2019, det
local numobs=r(N)
disp(`numobs')

*Convert to bar graph so you can stack
gen D_temp = .
replace D_temp = 1 if year<=2019
replace D_temp = 0 if year>2019

*Frequencies
twoway histogram layoff_minus_notice_new, freq discrete xlabel(-120(30)210) ///
	scheme(labor) lcolor(gray) fcolor(white) ///
    xtitle("Days between anticipated layoff date and notice date", height(5)) ///
	ytitle("Number of WARN notices", height(4)) ///
	graphregion(color(white)) bgcolor(white)
	
*Plot <=2019 and after as segmented bars
twoway histogram layoff_minus_notice_new, freq discrete xlabel(-120(30)210) blcolor(gs1) bfcolor(gs1) barw(2) ///
	|| histogram layoff_minus_notice_new if D_temp == 1, freq discrete blcolor(gs11) bfcolor(gs11) barw(2) ///
	xtitle("Days between anticipated layoff date and notice date", height(5)) ///
	ytitle("Number of WARN notices", height(4)) ///
	legend(order(2 "Before 2020" 1 "After 2020") col(1) ring(0) pos(1) region(color(none))) ///
	graphregion(color(white)) bgcolor(white)

gr export "$fig_dir\Figure1_histogram_pre_post_2020.pdf", as(pdf) replace

*What fraction of notices filed between 40 and 80 days before anticipated layoffs
count if layoff_minus_notice_new!=. & year<=2019
count if layoff_minus_notice_new>=40 & layoff_minus_notice_new<=80 & year<=2019

*Average workers affected by WARN notice
*Have to do it with the individual level data here
*Roughly 110
preserve
collapse (mean) num_affected
list
restore

*Section 2.4.1 fraction of notices with less than 50 days notice
*More than 25% of the issued notices have fewer than 50 people laid off
count if num_affected!=.
count if num_affected<50
count if num_affected<25

*Figure A4
*How the advance notice duration varies over the cycle
// preserve
collapse (mean) mean_layoff_minus_notice=layoff_minus_notice ///
	(median) median_layoff_minus_notice=layoff_minus_notice ///
	(p10) p10_layoff_minus_notice = layoff_minus_notice ///
	(p25) p25_layoff_minus_notice = layoff_minus_notice ///
	(p75) p75_layoff_minus_notice = layoff_minus_notice ///
	(p90) p90_layoff_minus_notice = layoff_minus_notice ///
	(mean) month_notice = month_notice ///
	(mean) year_notice=year_notice, ///
	by(time_notice)

*rename time_notice time
*Making a nice plot
cap drop _merge
merge 1:1 time using "$data_dir\data_input\recession_shading.dta"
*Changing current month to recession
replace recessm_usecon=1 if recessm_usecon==.
*format time %tmCCYY

drop if time_notice==.
drop if year_notice<1996
drop if year_notice==1996 & month_notice<7
*Recession bars data go back to 1921
drop if year_notice==.
sort time_notice
*Give you the min for September 2001 (terrorist attacks)
sum median_layoff_minus_notice if year<=2019, det

*<=2019
*Plotting with recession bars
local ymin = 0
local ymax = 100
local step = 30
tempvar bar
gen `bar' = `ymax'

twoway 	bar `bar' time if recessm==1, base(`ymin') color(gs15) fi(100) lw(0) || ///
		(line p25_layoff_minus_notice time, lcolor(gs11)) ///
		(line median_layoff_minus_notice time, lcolor(gs6)) ///
		(line p75_layoff_minus_notice time, lcolor(gs1)) ///
		if year_notice<=2019, ///
		legend(on ring(0) bplacement(nwest) order(4 "75th percentile" 3 "Median" 2 "25th percentile") ///
		region(color(none)) col(1) size(*1.33)) ///
		ttitle(" ") tlabel(1998m1(24)2019m12, labsize(large)) ///
		ytitle("Advance notice (days)", axis(1) size(*1.33)) ///
		ylabel(`ymin'(`step')`ymax', labsize(large)) ///
		graphregion(color(white)) bgcolor(white)

*gr export "$figpath\notice_duration_p25_p50_p75_2019.png", as(png) replace
*gr export "$fig_dir\notice_duration_p25_p50_p75_2019.png", as(png) replace

*Also save in gph so can combine with post-2019 in one panel
*gr save "$figpath\notice_duration_p25_p50_p75_2019", replace
gr save "$fig_dir\temp\notice_duration_p25_p50_p75_2019", replace

*Post 2019
*Plotting with recession bars
local ymin = -150
local ymax = 90
tempvar bar
gen `bar' = `ymax'

twoway 	bar `bar' time if recessm==1, base(`ymin') color(gs15) fi(100) lw(0) || ///
		(line p25_layoff_minus_notice time, lcolor(gs11)) ///
		(line median_layoff_minus_notice time, lcolor(gs6)) ///
		(line p75_layoff_minus_notice time, lcolor(gs1)) ///
		if year_notice>2019, ///
		legend(on ring(0) bplacement(seast) order(4 "75th percentile" 3 "Median" 2 "25th percentile") ///
		region(color(none)) col(1) size(*1.33)) ///
		ttitle(" ") tlabel(2020m1(2)$stoptime, labsize(large)) ///
		ytitle("Advance notice (days)", axis(1) size(*1.33)) ///
		ylabel(`ymin' -120 -90 -60 -30 0 30 60 90, labsize(large)) ///
		graphregion(color(white)) bgcolor(white)
		
*gr export "$figpath\notice_duration_p25_p50_p75_2020.png", as(png) replace
*gr export "$fig_dir\notice_duration_p25_p50_p75_2020.png", as(png) replace

*Also save in gph so can combine with post-2019 in one panel
*gr save "$figpath\notice_duration_p25_p50_p75_2020", replace
gr save "$fig_dir\temp\notice_duration_p25_p50_p75_2020", replace

gr combine 	"$fig_dir\temp\notice_duration_p25_p50_p75_2019" ///
			"$fig_dir\temp\notice_duration_p25_p50_p75_2020", ///
			col(1) altshrink $scheme

*Save the combined graph
*gr export "$figpath\notice_duration_p25_p50_p75_2020.png", as(png) replace
gr export "$fig_dir\FigureA4_notice_duration_p25_p50_p75_combined.pdf", as(pdf) replace

******************************USE STATE-MONTH DATA******************************
*This data will be different from the one above because as long as we have
*notice month we are fine; whereas above we needed notice and layoff day

*37 states
use "$data_dir\data_input\final_dataset_by_timenotice_sa_cleaned.dta", clear

*Number of WARN events and affected workers (SA and NSA)
*Report NSA numbers in paper
preserve
collapse (sum) num_affected_sa (sum) warn_event_sa (sum) num_affected (sum) warn_event
list
restore
*Before 2020
preserve
collapse (sum) num_affected_sa (sum) warn_event_sa (sum) num_affected (sum) warn_event ///
	if year <2020
list
restore
*Since 2020
preserve
collapse (sum) num_affected_sa (sum) warn_event_sa (sum) num_affected (sum) warn_event ///
	if year >=2020
list
restore

*Average number of notices over the last 5 years
preserve
collapse (sum) num_affected_sa (sum) warn_event_sa, by(year)
collapse (mean) num_affected_sa (mean)warn_event_sa if year>=2014 & year<=2019
list, clean
restore

*Creating number of 0 monthly observations within each state
sort state time
cap drop D_zero
cap drop num_zero
gen D_zero = 1 if num_affected_sa==0
by state: egen num_zero = sum(D_zero)

*Start and end date for each state in the sample
sort state_num time
gen D_start = 1 if num_affected_sa!=. & l1.num_affected_sa==.
gen D_end = 1 if num_affected_sa!=. & f1.num_affected_sa==.
gen time_start = time if D_start==1
gen time_end = time if D_end==1
format time_start %tm
format time_end %tm

*Table 1
*Avg, median, SD, min, and max, # of zeros by state
preserve
collapse (mean) time_start (mean) time_end ///
	(mean) avg_num_affected_sa=num_affected_sa (median) med_num_affected_sa=num_affected_sa ///
	(sd) sd_num_affected_sa=num_affected_sa ///
	(min) min_num_affected_sa=num_affected_sa (max) max_num_affected_sa=num_affected_sa ///
	(mean) zero_num_affected_sa=num_zero, by(state)
list, clean
restore

*Automate Table 1 in excel 
* export file: (change sheet name if necessary)
putexcel set "$tables_dir\table1.xlsx", modify sheet(Sheet1)
*Identify the row that you want the state data to be exported in by creating an "order" variable 
* would use state_num variable, but the numbering doesn't align quite right 
sort state 
egen state_order = group(state)

local states AL AZ CA CO CT FL IA IL IN KS LA MD MI MN MO MS NC NJ NY OH OR PA SC TN TX VA WA WI 
foreach i_state of local states {
	di "STATE: `i_state'"
	
	*Identify the row 
	su state_order if state=="`i_state'"
	local order = r(mean)
	local row = `order' + 3 // 3 rows below the ordering (means 3 header rows)
	di "Row number: `row'"
	
	* Start date
	qui su time_start if state == "`i_state'"
	local startdate : di %tm r(max)
	di "Start date: `startdate'"
	* End date 
	qui su time_end if state == "`i_state'"
	local enddate : di %tm r(max)
	di "End date: `enddate'"
	* Median, mean, SD
	qui su num_affected_sa if state == "`i_state'", d
	local median = r(p50) 
	local mean = r(mean)
	local sd = r(sd)
	di "Median: `median'"
	di "Mean: `mean'"
	di "SD: `sd'"
	
	* Number of months with 0 affected workers 
	qui su num_zero if state == "`i_state'"
	local mean0 = r(mean)
	di "# months with 0 affected workers: `mean0'"
	di "----------------------"
	
	** Export numbers 
	* Columns: 
	*A-statename, B-start date; C-end date; D-avg; E-median; F-stand dev; G-0 workers 
	putexcel A`row' = "`i_state'"
	putexcel B`row' = "`startdate'"
	putexcel C`row' = "`enddate'"
	putexcel D`row' = `mean'
	putexcel E`row' = `median'
	putexcel F`row' = `sd'
	putexcel G`row' = `mean0'
}
cap drop state_order 

*Number of states at various dates
tab state if year==1990 & month==1 & num_affected_sa!=.
tab state if year==2000 & month==1 & num_affected_sa!=.
tab state if year==2006 & month==1 & num_affected_sa!=.
*Notice that in Jan 2019 there are 32 states in the sample but there are 33
*states in the sample overall
*That's because SC enters in 2009m1 but exists in 2012m11
tab state if year==2019 & month==1 & num_affected_sa!=.

***Table A1
*Average and standard deviation of the overall number of workers affected by WARN
egen state_id = group(state)
xtset state_id time
sum num_affected_sa if year<2020, det

*Summary statistics of unemployment rates

*WARN_{s,t}: row 1
sum num_affected_sa if year<2020, det
*UI claims: row 4
sum ui_claims_sa if num_affected_sa!=. & year<2020, det
*U_{s,t}: row 5
sum ur_sa if num_affected_sa!=. & year<2020, det
*\Delta U_{s,t}:L row 6
sum d1_ur_sa if num_affected_sa!=. & year<2020, det
*E_{s,t}: row 7
sum emp_priv_ces_sa if num_affected_sa!=. & year<2020, det
*\Delta E_{s,t}: row 8
sum d1_emp_priv_ces_sa if num_affected_sa!=. & year<2020, det


** Automate WARN, UI, u and delta U, PE, delta PE for Table A1
putexcel set "$tables_dir\tableA1.xlsx", modify sheet(Sheet1)
foreach var of varlist num_affected_sa ui_claims_sa ur_sa d1_ur_sa emp_priv_ces_sa d1_emp_priv_ces_sa {
	*Excel rows for each variable 
	if "`var'" == "num_affected_sa" {
		local row = 2
	}
	else if "`var'" == "ui_claims_sa" {
		local row = 5
	}
	
	else if "`var'" == "ur_sa" {
		local row = 6
	}
	else if "`var'" == "d1_ur_sa" {
		local row = 7
	}
	else if "`var'" == "emp_priv_ces_sa" {
		local row = 8
	}
	else if "`var'" == "d1_emp_priv_ces_sa" {
		local row = 9
	}
	
	sum `var' if num_affected_sa!=. & year<2020, det 
	local mean = r(mean)
	local median = r(p50)
	local sd = r(sd)
	local min = r(min)
	local max = r(max)
	local obs = r(N)
	

	qui putexcel B`row' = `mean'
	qui putexcel C`row' = `median'
	qui putexcel D`row' = `sd'
	qui putexcel E`row' = `min'
	qui putexcel F`row' = `max'
	qui putexcel G`row' = `obs'
}


tab state if num_affected_sa!=.
gen step1 = 1 if num_affected_sa!=.

*Mark states that are in the sample as of January, 2006
cap drop D_num_affected
gen D_num_affected = 0
replace D_num_affected = 1 if num_affected!=. & year==2006 & month == 1
replace D_num_affected = 1 if l1.D_num_affected==1
*States in sample
tab state if D_num_affected==1
*save "$save_datapath\step1_final_dataset_by_timenotice_sa.dta", replace
*drop some variables

save "$data_dir\data_output\step1_final_dataset_by_timenotice_sa_cleaned.dta", replace

********************************************************************************
*Relate to Mass Layoff Statistics program (BLS)
*Table A1
*use "$save_datapath\step1_final_dataset_by_timenotice_sa.dta", clear
use "$data_dir\data_output\step1_final_dataset_by_timenotice_sa_cleaned.dta", clear

*Table A1: row 2
sum initial_claimants_sa_mls if num_affected_sa!=., det

putexcel set "$tables_dir\tableA1.xlsx", modify sheet(Sheet1)
local mean = r(mean)
local median = r(p50)
local sd = r(sd)
local min = r(min)
local max = r(max)
local obs = r(N)
qui putexcel B3 = `mean'
qui putexcel C3 = `median'
qui putexcel D3 = `sd'
qui putexcel E3 = `min'
qui putexcel F3 = `max'
qui putexcel G3 = `obs'

*What fraction of initial claims are covered by the states in our sample
collapse (sum) ui_claims, by(year) //9,688,423
list if year==2018, clean
*Compare this number to the annual sum in 2018 of NSA initial claims here:
*https://fred.stlouisfed.org/series/ICNSA
*(11,486,539)
*9,688,423/11,486,539=84.3 percent


********************************************************************************
*Relate to JOLTS

*use "$save_datapath\step1_final_dataset_by_timenotice_sa.dta", clear
use "$data_dir\data_output\step1_final_dataset_by_timenotice_sa_cleaned.dta", clear

collapse (sum) num_affected num_affected_sa (mean) year (mean) month if D_num_affected==1, by (time)

*merge 1:1 time using "$save_datapath\ljltpl.dta", keep(3)
merge 1:1 time using "$data_dir\data_input\ljltpl.dta", keep(3)
drop _merge
*merge 1:1 time using "$save_datapath\ljltpla.dta", keep(3)
merge 1:1 time using "$data_dir\data_input\ljltpla.dta", keep(3)
drop _merge
rename ljltpl_usecon layoffs_JOLTS_NSA
rename ljltpla_usecon layoffs_JOLTS_SA
label variable layoffs_JOLTS_NSA "JOLTS layoffs and discharges, total priv., NSA"
label variable layoffs_JOLTS_SA "JOLTS layoffs and discharges, total priv., SA by BLS"

*Table A1: row 3
sum layoffs_JOLTS_SA if year<2020, det

putexcel set "$tables_dir\tableA1.xlsx", modify sheet(Sheet1)
local mean = r(mean)
local median = r(p50)
local sd = r(sd)
local min = r(min)
local max = r(max)
local obs = r(N)
qui putexcel B4 = `mean'
qui putexcel C4 = `median'
qui putexcel D4 = `sd'
qui putexcel E4 = `min'
qui putexcel F4 = `max'
qui putexcel G4 = `obs'

*save "$save_datapath\step1_final_dataset_by_timenotice_sa_JOLTS.dta", replace
save "$data_dir\data_output\step1_final_dataset_by_timenotice_sa_JOLTS.dta", replace

********************************************************************************
*Fraction of MLS initial UI claimants and WARN layoffs by industry
*MLS data about initial claimants and MLS events by industry
use "$data_dir\data_input\MLS_NAICS.dta", clear

collapse (sum) layoff_event (sum) initial_claimants, by(naics_2digit)

foreach var of varlist layoff_event initial_claimants {
	egen `var'_total = sum(`var')
	gen `var'_pct = (`var'/`var'_total)*100
}

save "$data_dir\data_output\MLS_collapse", replace

*Use the WARN appended data with NAICS codes for 2019
use "$data_dir\data_output\step1_ind_notices_appended.dta", replace
keep if year_notice==2019
drop if naics_2digit == . // some observations that are provided to us are coded incorrectly 


* collapse all states for overall, and create an overall percentage in 2019 
collapse (sum) warn_event (sum) num_affected, by(naics_2digit)
foreach var of varlist warn_event num_affected {
	egen `var'_total = sum(`var')
	gen `var'_pct = (`var'/`var'_total)*100
	
}

* merge with the overall MLS pctortions 
merge 1:1 naics_2digit using "$data_dir\data_output\MLS_collapse", nogen 

* export numbers 
drop *total
// export excel using "$save_datadropbox\WARN_NAICS_counts.xlsx", ///
// 	cell(A3) sheetmodify keepcellfmt
	
** shortened industry labels 
	label def naics_shortL 1 "Agriculture" /// 11
				 2 "Mining" /// 21
				 3 "Utilities" /// 22
				 4 "Construction" /// 23
				 5 "Manufacturing" /// 31-33
				 6 "Wholesale trade" /// 42
				 7 "Retail trade" /// 44-45
				 8 "Transportation and warehousing" /// 48-49
				 9 "Information" /// 51
				 10 "Finance and insurance" /// 52 
				 11 "Real estate & rental leasing" ///53
				 12 "Prof., sci., & techn. services" /// 54
				 13 "Mgmt. of companies & enterprises" /// 55
				 14 "Admin., support, waste services" /// 56
				 15 "Educational services" /// 61
				 16 "Hlth care & social assistance" /// 62
				 17 "Arts, entertainment, & rec." /// 71
				 18 "Accommodation and food services" /// 72
				 19 "Other srvcs (not public admin.)" /// 81 
				 20 "Public administration" /// 92
				 , replace 
label val naics_2digit naics_shortL

* begin chart
label var num_affected_pct "WARN Layoffs"
label var initial_claimants_pct "MLS Initial Claimants"
graph hbar (asis) num_affected_pct initial_claimants_pct, over(naics_2digit, sort(num_affected_pct) descending label(labsize(small))) ///
	bar(1, bcolor(gs5)) bar(2, bcolor(gs10)) ///
	graphregion(color(white)) /// 
	ylabel(,labsize(small)) ///
	ytitle("Percent of affected workers", size(small)) ///
	legend(ring(0) position(4) col(1) size(small) symxsize(*.2) symysize(*.4) region(color(none))) ///
	name("initial_claimants_pct", replace)
graph export "$fig_dir\FigureA3_WARN_layoffs_pct.pdf", as(pdf) replace
	
cap log close ProgramLog
	
	
	
	
	