*Plot NSA MLS initial claimants together with sum of NSA num affected in WARN
clear all
set more off 
cap log close

*Close log file and start logging
cap log close ProgramLog
log using "$root_dir\logs\step2_prelim_evidence", replace name(ProgramLog)

global scheme "scheme(s1mono)"

*Input
*Where the data are stored
global data_dir "$root_dir\data"

*Output
*Where to store figures
global fig_dir "$root_dir\figures"

********************************************************************************
*Figure A1
use "$data_dir\data_output\step1_final_dataset_by_timenotice_sa_cleaned.dta", clear
xtset state_num time

merge m:1 time using "$data_dir\data_input\recession_shading1990.dta"
gen time_year = time
format time_year %tmCCYY

*Everything before Dec 2019
preserve
drop if year<1996 | (year==1996 & month<=6)
drop if year >=2020

*Create 3mma for num_affected_sa
sort state_num time
cap drop num_affected_sa_3mma
gen num_affected_sa_3mma = .
replace num_affected_sa_3mma=(num_affected_sa+l1.num_affected_sa+l2.num_affected_sa)/3

cap gen num_affected_k = num_affected/1000

local states CA TX FL NY PA IL OH NC
*local states CA
foreach state of local states {
	
	if "`state'"=="CA" {
		local ymax = 20
	}
	else if "`state'"=="TX" {
		local ymax = 15
	}
	else if "`state'"=="FL" {
		local ymax = 10
	}
	else if "`state'"=="NY" {
		local ymax = 12
	}
	else if "`state'"=="PA" {
		local ymax = 10
	}
	else if "`state'"=="IL" {
		local ymax = 20
	}
	else if "`state'"=="OH" {
		local ymax = 8
	}
	else if "`state'"=="NC" {
		local ymax = 8
	}
	
	if "`state'"=="CA" || "`state'"=="IL" || "`state'"=="OH" || "`state'"=="NC" || "`state'"=="NY" {
		local interval = `ymax'/4
	}
	else {
		local interval = `ymax'/5
	}
	
	*local ymax = 8000
	tempvar bar
	gen `bar' = `ymax'
	
	twoway 	bar `bar' time_year if recessm==1, base(0) color(gs15) fi(100) lw(0) || ///
		(line num_affected_k time_year if state=="`state'", yaxis(1) lcolor(gs1)) ///
		, ///
		legend(off) ///
		title("`state'") ttitle(" ") tlabel(1998m1(36)2019m12) ///
		ytitle("Thousands (NSA)", axis(1)) ///
		yla(0(`interval')`ymax') ///
		graphregion(color(white)) bgcolor(white)
		
	gr export "$fig_dir\temp\num_affected_`state'.pdf", as(pdf) replace
	*Saving in STATA format to graph combine after the loop
	gr save "$fig_dir\temp\num_affected_`state'", replace
	
}

gr combine 	"$fig_dir\temp\num_affected_CA" ///
			"$fig_dir\temp\num_affected_TX" ///
			"$fig_dir\temp\num_affected_FL" ///
			"$fig_dir\temp\num_affected_NY" ///
			"$fig_dir\temp\num_affected_PA" ///
			"$fig_dir\temp\num_affected_IL" ///
			"$fig_dir\temp\num_affected_OH" ///
			"$fig_dir\temp\num_affected_NC", ///
			rows(4) cols(2) altshrink $scheme iscale(2)
			
gr export "$fig_dir\FigureA1_num_affected_comb.pdf", as(pdf) replace
restore

*****************After Dec 2019
*Figure A2
drop if year<2020
cap gen num_affected_k = num_affected/1000

*Create 3mma for num_affected_sa
sort state_num time
cap drop num_affected_sa_3mma
gen num_affected_sa_3mma = .
replace num_affected_sa_3mma=(num_affected_sa+l1.num_affected_sa+l2.num_affected_sa)/3

local states CA TX FL NY PA IL OH NC
*local states CA
foreach state of local states {
	
	if "`state'"=="CA" {
		local ymax = 300
	}
	else if "`state'"=="TX" {
		local ymax = 40
	}
	else if "`state'"=="FL" {
		local ymax = 40
	}
	else if "`state'"=="NY" {
		local ymax = 90
	}
	else if "`state'"=="PA" {
		local ymax = 25
	}
	else if "`state'"=="IL" {
		local ymax = 20
	}
	else if "`state'"=="OH" {
		local ymax = 20
	}
	else if "`state'"=="NC" {
		local ymax = 10
	}
	
	if "`state'"=="CA" || "`state'"=="NY" ///
	{
		local interval = `ymax'/3
	}
	else if "`state'"=="PA" || "`state'"=="NC" {
		local interval = `ymax'/5
	}
	else {
		local interval = `ymax'/4
	}
	
	*local ymax = 8000
	tempvar bar
	gen `bar' = `ymax'
	
	twoway 	bar `bar' time if recessm==1, base(0) color(gs15) fi(100) lw(0) || ///
		(line num_affected_k time if state=="`state'", yaxis(1) lcolor(gs1)) ///
		, ///
		legend(off) ///
		title("`state'") ttitle(" ") tlabel(2020m1(3)$stoptime) ///
		ytitle("Thousands (NSA)", axis(1)) ///
		yla(0(`interval')`ymax',labsize(medium)) ///
		graphregion(color(white)) bgcolor(white)
		
	gr export "$fig_dir\temp\num_affected_2020_`state'.pdf", as(pdf) replace
	*Saving in STATA format to graph combine after the loop
	gr save "$fig_dir\temp\num_affected_2020_`state'", replace
	
}

gr combine 	"$fig_dir\temp\num_affected_2020_CA" ///
			"$fig_dir\temp\num_affected_2020_TX" ///
			"$fig_dir\temp\num_affected_2020_FL" ///
			"$fig_dir\temp\num_affected_2020_NY" ///
			"$fig_dir\temp\num_affected_2020_PA" ///
			"$fig_dir\temp\num_affected_2020_IL" ///
			"$fig_dir\temp\num_affected_2020_OH" ///
			"$fig_dir\temp\num_affected_2020_NC", ///
			rows(4) cols(2) altshrink $scheme iscale(2)
			
gr export "$fig_dir\FigureA2_num_affected_2020_comb.pdf", as(pdf) replace

********************************************************************************
*Figure 2
*MLS VS. WARN

use "$data_dir\data_output\step1_final_dataset_by_timenotice_sa_cleaned.dta", clear

replace num_affected_sa = num_affected_sa/1000
replace initial_claimants_sa_mls = initial_claimants_sa_mls/1000

* setting range of axes
local step = 20
local ymin = 0
local ymax = 80
local step2 = 50
local ymin2 = 50
local ymax2 = 275

*SA
collapse (sum) num_affected_sa (sum) initial_claimants_sa_mls if D_num_affected==1, by(time)
label variable num_affected_sa "Number of Workers Affected by WARN Notices (SA)"
label variable initial_claimants_sa_mls "Number of MLS initial claimants (Thousands, SA)"
tempvar bar
gen `bar' = `ymax'
*merge 1:1 time using "$save_datapath\recession_shading.dta"
merge 1:1 time using "$data_dir\data_input\recession_shading2006.dta"
format time %tmCCYY

*For this figure, drop everything after MLS is not available
local firstobs = tm(2006m1)
local lastobs=tm(2013m5)
drop if time>`lastobs'

twoway 	bar `bar' time if recessm==1, base(`ymin') color(gs15) fi(100) lw(0) || ///
		(line num_affected_sa time, yaxis(1) lcolor(gs1)) || ///
		(line initial_claimants_sa_mls time, yaxis(2) lcolor(gs10)) ///
		if initial_claimants_sa_mls!=0 ///
		, ///
		legend(on ring(0) bplacement(neast) order(2 "WARN (left)" 3 "MLS (right)") region(color(none)) col(1)) ///
		ttitle(" ") tlabel(`firstobs'(12)`lastobs') ///
		ytitle("WARN layoffs (Thousands, SA)", axis(1)) ///
		yla(`ymin'(`step')`ymax', axis(1)) ///
		yla(`ymin2'(`step2')`ymax2', axis(2)) ///
		graphregion(color(white)) bgcolor(white)
		
gr export "$fig_dir\Figure2_WARN_MLS_SA.pdf", as(pdf) replace

********************************************************************************
*Figure 3
*Plot alongside JOLTS (SA)
clear all

use "$data_dir\data_output\step1_final_dataset_by_timenotice_sa_JOLTS.dta", clear

replace num_affected_sa = num_affected_sa/1000

* setting range of axes
local ymin = 0
local ymax = 80
local step = 10
tempvar bar
gen `bar' = `ymax'
local ymin2 = 1250
local ymax2 = 3000
local step2 = 500

label variable num_affected_sa "Num workers affected by WARN notices (SA)"

merge 1:1 time using "$data_dir\data_input\recession_shading2006.dta"
gen temp_time = time
format temp_time %tmCCYY
keep if _merge==3
*format time %tmCCYY

*SA
label variable layoffs_JOLTS_SA "JOLTS layoffs (total private, SA)"

twoway 	bar `bar' temp_time if recessm==1, base(`ymin') color(gs15) fi(100) lw(0) || ///
		(line num_affected_sa temp_time, yaxis(1) lcolor(gs1)) || ///
		(line layoffs_JOLTS_SA temp_time, yaxis(2) lcolor(gs10)) ///
		if year<=2019, ///
		legend(on ring(0) bplacement(neast) order(2 "WARN (left)" 3 "JOLTS (right)") ///
			region(color(none)) col(1) size(*1.33)) ///
		ttitle(" ") tlabel(2007m1(24)2019m12) ///
		ytitle("WARN layoffs (Thousands, SA)", axis(1)) ///
		ytitle("JOLTS layoffs (Thousands, SA)", axis(2)) ///
		yla(`ymin'(`step')`ymax', axis(1)) ///
		yla(`ymin2'(`step2')`ymax2', axis(2)) ///
		graphregion(color(white)) bgcolor(white) ///
		yline(0, lstyle(grid)) // Add line at 0 //
	
gr save "$fig_dir\temp\WARN_JOLTS_SA_2019", replace

* setting range of axes
local step1 = 100
local ymin1 = 0
local ymax1 = 600
local step2 = 5000
local ymin2 = 0
local ymax2 = 15000
tempvar bar
gen `bar' = `ymax1'

twoway 	bar `bar' time if recessm==1, base(`ymin') color(gs15) fi(100) lw(0) || ///
		(line num_affected_sa time, yaxis(1) lcolor(gs1)) || ///
		(line layoffs_JOLTS_SA time, yaxis(2) lcolor(gs10)) ///
		if year>=2020, ///
		legend(on ring(0) bplacement(neast) order(2 "WARN (left)" 3 "JOLTS (right)") ///
			region(color(none)) col(1) size(*1.33)) ///
		ttitle(" ") tlabel(2020m1(2)$stoptime) ///
		ytitle("WARN layoffs (Thousands, SA)", axis(1)) ///
		ytitle("JOLTS layoffs (Thousands, SA)", axis(2)) ///
		yla(`ymin1'(`step1')`ymax1', axis(1)) ///
		yla(`ymin2'(`step2')`ymax2', axis(2)) ///
		graphregion(color(white)) bgcolor(white) ///
		yline(0, lstyle(grid)) // Add line at 0 //

*gr export "$figpath\\WARN_JOLTS_SA.png", as(png) replace
*gr export "$figpath_dropbox\\WARN_JOLTS_SA_2020.png", as(png) replace
gr save "$fig_dir\temp\WARN_JOLTS_SA_2020", replace

gr combine 	"$fig_dir\temp\WARN_JOLTS_SA_2019" ///
			"$fig_dir\temp\WARN_JOLTS_SA_2020", ///
			col(1) altshrink $scheme
			
gr export "$fig_dir\temp\Figure3_WARN_JOLTS_SA_combined.pdf", as(pdf) replace


cap log close ProgramLog
