*Run lead regressions with state-level data

clear all
set more off 
cap log close

*Close log file and start logging
cap log close ProgramLog
log using "$root_dir\logs\step3_state_level_regression", replace name(ProgramLog)

*Have to set path for Haver
*set haverdir O:Haver\DATA

// global save_datapath "H:\WARN_project\FRBC_WP2022\data"
global data_dir "$root_dir\data"
global tab_dir "$root_dir\tables"

********************************************************************************
use "$data_dir\data_output\step1_final_dataset_by_timenotice_sa_cleaned.dta", clear

*Converting to 1000s so that one unit increase in WARN is a 1000 increase in the number affected
gen temp = num_affected_sa
gen temp2 = temp/1000
drop num_affected_sa temp
rename temp2 num_affected_sa
	
*Putting emp back into levels as opposed to 1000s
replace emp_priv_ces_sa =1000*emp_priv_ces_sa
	
tab state if num_affected_sa!=.

* UI claims
eststo reg_ui_claims: areg ui_claims_sa l1.num_affected_sa l2.num_affected_sa ///
	l1.ui_claims_sa l2.ui_claims_sa ///
	l1.d1_ur_sa l2.d1_ur_sa ///
	l1.d1_emp_priv_ces_sa l2.d1_emp_priv_ces_sa if year<=2019 [aweight=emp_priv_ces_sa], absorb(state) cluster(state)
estadd ysumm, mean sd min max
estadd scalar R_squared = e(r2)
estadd scalar Observations = e(N)
cap drop reg_ui_claims_sample
gen reg_ui_claims_sample = e(sample)
test l1.num_affected_sa l2.num_affected_sa 
return list
estadd scalar pvalue = r(p)

*Effects are small: std. dev. of intial UI claims changes is about 1.9k
gen d1_ui_claims_sa = d1.ui_claims_sa
sum d1_ui_claims_sa if reg_ui_claims_sample==1 & year<=2019 [aweight=emp_priv_ces_sa], det

* Change in unemployment rate
eststo reg_ur: areg d1_ur_sa l1.num_affected_sa l2.num_affected_sa  ///
	l1.d1_ur_sa l2.d1_ur_sa ///
	l1.ui_claims_sa l2.ui_claims_sa  ///
	l1.d1_emp_priv_ces_sa l2.d1_emp_priv_ces_sa if year<=2019 [aweight=emp_priv_ces_sa], absorb(state) cluster(state)
cap drop reg_ur_sample
gen reg_ur_sample = e(sample)
estadd ysumm, mean sd min max
estadd scalar R_squared = e(r2)
estadd scalar Observations = e(N)

test l1.num_affected_sa l2.num_affected_sa 
return list
estadd scalar pvalue = r(p)

*Effect is small: std. dev. of ur changes is 0.13.
sum d1_ur_sa if reg_ui_claims_sample==1 & year<=2019 [aweight=emp_priv_ces_sa], det
	
* Change in employment
		
eststo reg_emp_priv_ces: areg d1_emp_priv_ces_sa l1.num_affected_sa l2.num_affected_sa  ///
	l1.d1_emp_priv_ces_sa l2.d1_emp_priv_ces_sa  ///
	l1.d1_ur_sa l2.d1_ur_sa  ///
	l1.ui_claims_sa l2.ui_claims_sa  if year<=2019 [aweight=emp_priv_ces_sa], absorb(state) cluster(state)
estadd ysumm, mean sd min max
estadd scalar R_squared = e(r2)
estadd scalar Observations = e(N)
test l1.num_affected_sa l2.num_affected_sa 
return list
estadd scalar pvalue = r(p)

*Effect is small: std. dev. of private employment growth is about 17k.
sum d1_emp_priv_ces_sa if reg_ui_claims_sample==1 & year<=2019 [aweight=emp_priv_ces_sa], det

*** Table 2 
esttab reg_ui_claims reg_ur reg_emp_priv_ces using "$tab_dir\table2.csv", ///
	keep(L.num_affected_sa L2.num_affected_sa) ///
	se(%8.4f) ///
	star(* 0.1 ** 0.05 *** 0.01) scalar(pvalue Observations R_squared) noobs ///
	nonotes replace

cap log close ProgramLog
